@@ -91,13 +91,17 @@ struct _HDStatusAreaPrivate
 G_DEFINE_TYPE (HDStatusArea, hd_status_area, GTK_TYPE_WINDOW);
 
 static gboolean
-button_press_event_cb (GtkWidget      *widget,
+button_release_event_cb (GtkWidget      *widget,
                        GdkEventButton *event,
                        HDStatusArea   *status_area)
 {
   HDStatusAreaPrivate *priv = status_area->priv;
 
   gtk_widget_show (priv->status_menu);
+  if (!GTK_WIDGET_VISIBLE (priv->status_menu))
+    /* Failed to show the status menu because it got deleted.
+     * Make sure it doesn't retain the grab. */
+    gtk_grab_remove (GTK_WIDGET (priv->status_menu));
 
   return TRUE;
 }
@@ -177,9 +181,9 @@ hd_status_area_init (HDStatusArea *status_area)
   priv->status_plugins = NULL;
 
   /* Create Status area UI */
-  gtk_widget_add_events (GTK_WIDGET (status_area), GDK_BUTTON_PRESS_MASK);
-  g_signal_connect (G_OBJECT (status_area), "button-press-event",
-                    G_CALLBACK (button_press_event_cb), status_area);
+  gtk_widget_add_events (GTK_WIDGET (status_area), GDK_BUTTON_RELEASE_MASK);
+  g_signal_connect (G_OBJECT (status_area), "button-release-event",
+                    G_CALLBACK (button_release_event_cb), status_area);
   gtk_widget_set_app_paintable (GTK_WIDGET (status_area), TRUE);
   gtk_widget_set_size_request (GTK_WIDGET (status_area), -1, STATUS_AREA_HEIGHT);
 
@@ -380,7 +384,7 @@ hd_status_area_plugin_added_cb (HDPluginManager *plugin_manager,
       if (permanent_item && strcmp (value, permanent_item) == 0)
         {
           image = priv->special_item_image [i];
-          g_object_set_qdata (plugin, quark_hd_status_area_image, image);
+          g_object_set_qdata_full (plugin, quark_hd_status_area_image, image, (GDestroyNotify) gtk_widget_destroy);
 
           g_free (value);
           break;
